@@ -1,4 +1,4 @@
-import logging
+from __future__ import unicode_literals
 import sys
 import time
 import traceback
@@ -6,18 +6,9 @@ from unittest.result import TestResult
 from unittest.signals import registerResult
 import warnings
 
-from green.output import Colors, GreenStream
+from green.output import Colors, debug, GreenStream
 from green.version import pretty_version
 
-global debug_level
-debug_level = 0
-
-
-def debug(message, level=0):
-    """So we can tune how much debug output we get when we turn it on."""
-    if level <= debug_level:
-        logging.debug(message)
-
 
 
 class GreenTestResult(TestResult):
@@ -46,14 +37,6 @@ class GreenTestResult(TestResult):
         self.passing = []
 
 
-    def getDescription(self, test):
-        doc_first_line = test.shortDescription()
-        if self.descriptions and doc_first_line:
-            return '\n'.join((str(test), doc_first_line))
-        else:
-            return str(test)
-
-
     def startTest(self, test):
         super(GreenTestResult, self).startTest(test)
         # Get our bearings
@@ -133,7 +116,7 @@ class GreenTestResult(TestResult):
     def addSkip(self, test, reason):
         super(GreenTestResult, self).addSkip(test, reason)
         self._reportOutcome(
-                test, 's', self.colors.skipped, err=None, reason=reason)
+                test, 's', self.colors.skipped, reason)
 
 
     def addExpectedFailure(self, test, err):
@@ -143,7 +126,7 @@ class GreenTestResult(TestResult):
 
     def addUnexpectedSuccess(self, test):
         super(GreenTestResult, self).addUnexpectedSuccess(test)
-        self._reportOutcome(test, 'u', self.colors.expectedFailure)
+        self._reportOutcome(test, 'u', self.colors.unexpectedSuccess)
 
 
     def printErrors(self):
@@ -196,7 +179,7 @@ class GreenTestRunner(object):
 
         stream - Any stream passed in will be wrapped in a GreenStream
         colors - A Colors object.  Default colors will be used if not provided.
-        Used to determine whether html mode is desired as well.
+                 Used to determine whether html mode is desired as well.
         """
         if stream is None:
             stream = sys.stderr
@@ -222,7 +205,6 @@ class GreenTestRunner(object):
         if self.colors.html:
             self.stream.write(
                     '<div style="font-family: Monaco, \'Courier New\', monospace; color: rgb(170,170,170); background: rgb(0,0,0); padding: 14px;">')
-        python_version = ".".join([str(x) for x in sys.version_info[0:3]])
         if self.verbosity > 2:
             self.stream.writeln(self.colors.bold(pretty_version() + "\n"))
         result = self._makeResult()
