@@ -1,12 +1,16 @@
+from __future__ import unicode_literals
 import os.path
 import sys
 
 try:
     import coverage
-except:
+except: # pragma nocover
     coverage = None
 
 __version__ = open(os.path.join(os.path.dirname(__file__), 'VERSION')).read().strip()
+if sys.version_info[0] == 2: # pragma nocover
+    from __builtin__ import unicode  # just so the linter stops complaining
+    __version__ = unicode(__version__)
 
 
 def pretty_version():
